<?php

namespace Drupal\entity_value_inheritance\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * Event used for running save entity functionality.
 */
class InheritanceSaveEntityEvent extends Event {


  /**
   * Inheritance entities.
   *
   * @var \Drupal\entity_value_inheritance\Entity\InheritanceInterface[]
   */
  protected array $inheritances = [];

  /**
   * List of all destination entities.
   *
   * @var \Drupal\Core\Entity\EntityInterface[]
   */
  protected array $destinationEntities = [];

  /**
   * Constructor.
   */
  public function __construct(
    array $inheritances,
    array $destinationEntities = []
  ) {
    $this->inheritances = $inheritances;
    $this->destinationEntities = $destinationEntities;
  }

  /**
   * Return a list of all destination entities.
   *
   * @return \Drupal\Core\Entity\EntityInterface[]
   *   List of destination entities.
   */
  public function getDestinationEntities(): array {
    return $this->destinationEntities;
  }

  /**
   * Return a list of all inheritances.
   *
   * @return \Drupal\entity_value_inheritance\Entity\InheritanceInterface[]
   *   List of Inheritances.
   */
  public function getInheritances(): array {
    return $this->inheritances;
  }

}
